@@ -21,7 +21,14 @@ module Gem2Deb
 
   class GemInstaller < Installer
 
-    INSTALL_BLACKLIST = %w[
+    def self.get_list(name, obsolete_msg = nil)
+      if ENV.has_key?(name) && obsolete_msg
+        $stderr.puts("W: #{obsolete_msg}")
+      end
+      ENV.fetch(name, '').split
+    end
+
+    INSTALL_EXCLUDE_LIST = %w[
       bin/console
       bin/setup
       coverage/*
@@ -33,11 +40,11 @@ module Gem2Deb
       spec/*
       test/*
       tests/*
-    ] + ENV.fetch('DH_RUBY_GEM_INSTALL_BLACKLIST_APPEND', '').split
+    ] + get_list('DH_RUBY_GEM_INSTALL_EXCLUDE') + get_list('DH_RUBY_GEM_INSTALL_BLACKLIST_APPEND', 'DH_RUBY_GEM_INSTALL_BLACKLIST_APPEND is deprecated, please use DH_RUBY_GEM_INSTALL_EXCLUDE instead (needs gem2deb >= 1.6~)')
 
-    INSTALL_WHITELIST = %w[
+    INSTALL_INCLUDE_LIST = %w[
       VERSION*
-    ] + ENV.fetch('DH_RUBY_GEM_INSTALL_WHITELIST_APPEND', '').split
+    ] + get_list('DH_RUBY_GEM_INSTALL_INCLUDE') + get_list('DH_RUBY_GEM_INSTALL_WHITELIST_APPEND is deprecated, please use DH_RUBY_GEM_INSTALL_INCLUDE instead (needs gem2deb >= 1.6~)')
 
     class NoGemspec < Exception
       def initialize(root)
@@ -47,12 +54,12 @@ module Gem2Deb
 
     protected
 
-    def whitelist
-      INSTALL_WHITELIST
+    def include_list
+      INSTALL_INCLUDE_LIST
     end
 
-    def blacklist
-      INSTALL_BLACKLIST
+    def exclude_list
+      INSTALL_EXCLUDE_LIST
     end
 
     def install_files_and_build_extensions
@@ -76,14 +83,14 @@ module Gem2Deb
           gemspec_data.files = Dir['**/*']
         end
         gemspec_data.files.reject! do |entry|
-          if whitelist.any? { |incl| File.fnmatch(incl, entry) }
-            false # whitelisted, don't reject
+          if include_list.any? { |incl| File.fnmatch(incl, entry) }
+            false # included, don't reject
           else
             if !entry.index('/')
               true # exclude all top-level files by default
             else
-              # reject if blacklisted
-              blacklist.any? { |exclude| File.fnmatch(exclude, entry) }
+              # reject if excluded
+              exclude_list.any? { |exclude| File.fnmatch(exclude, entry) }
             end
           end
         end
@@ -149,6 +156,11 @@ module Gem2Deb
             FileUtils::Verbose.rm_rf('extensions')
           end
 
+          # remove empty plugins/ directory
+          if Dir.exists?('plugins') && Dir.empty?('plugins')
+              FileUtils::Verbose.rmdir('plugins')
+          end
+
           FileUtils::Verbose.cd(File.join('gems', "#{metadata.name}-#{metadata.version}")) do
             # remove source of compiled extensions
             gemspec_data.extensions.each do |ext|
@@ -167,6 +179,11 @@ module Gem2Deb
             if File.directory?('lib')
               run 'find', 'lib/', '-type', 'd', '-empty', '-delete'
             end
+
+            # remove empty directories inside ext/
+            if File.directory?('ext')
+              run 'find', 'ext/', '-type', 'd', '-empty', '-delete'
+            end
           end
         end
 
