@@ -24,6 +24,23 @@ module Gem2Deb
       @metadata = Gem2Deb::Metadata.new(@root)
     end
 
+    def install
+      install_files_and_build_extensions
+      update_shebangs
+      install_substvars
+      install_gemspec
+      install_changelog
+    end
+
+    def clean
+      run_make_clean_on_extensions
+    end
+
+    # The public API ends here
+    # ----------------8<----------------8<----------------8<-----------------
+
+    protected
+
     def install_files_and_build_extensions
 
       Gem2Deb::Banner.print "Install files"
@@ -45,8 +62,6 @@ module Gem2Deb
           end
         end
       end
-
-      install_changelog
     end
 
     def update_shebangs
@@ -66,8 +81,10 @@ module Gem2Deb
         else
           ruby_versions
         end
+      dependencies = metadata.get_debian_dependencies(false)
       File.open("debian/#{binary_package}.substvars", "a") do |fd|
         fd.puts "ruby:Versions=#{versions.join(' ')}"
+        fd.puts "ruby:Depends=#{dependencies.join(', ')}"
       end
     end
 
@@ -84,8 +101,12 @@ module Gem2Deb
           target = File.join(destdir(:root), "/usr/share/rubygems-integration/#{version}/specifications/#{metadata.name}-#{metadata.version}.gemspec")
           puts "generating gemspec at #{target}"
           FileUtils.mkdir_p(File.dirname(target))
+          gemspec = metadata.gemspec.dup
+          # Do not include extensions in the gemspec to avoid bundler not being able to
+          # indentify if the extensions were correctly built. For more info check Bug #972702.
+          gemspec.extensions = []
           File.open(target, 'w') do |file|
-            file.write(metadata.gemspec.to_ruby)
+            file.write(gemspec.to_ruby)
           end
         end
       end
@@ -105,7 +126,12 @@ module Gem2Deb
       end
     end
 
-    protected
+    def install_changelog
+      changelog = Dir.glob(File.join(root, 'CHANGELOG*')).first
+      if changelog
+        run("dh_installchangelogs", "-p#{binary_package}", changelog, "upstream")
+      end
+    end
 
     def all_ruby_versions_supported?
       ruby_versions == supported_ruby_versions
@@ -198,7 +224,7 @@ module Gem2Deb
         next if File.directory?(path)
         atomic_rewrite(path) do |input, output|
           old = input.gets
-          if old =~ /ruby/ or old !~ /^#!/
+          if old =~ /^#!\s*\/.*ruby/
             puts "Rewriting shebang line of #{path}" if @verbose
             output.puts "#!#{ruby_binary}"
             unless old =~ /#!/
@@ -236,17 +262,6 @@ module Gem2Deb
       end
     end
 
-    def installed_ruby_files
-      Dir["debian/#{binary_package}/usr/lib/ruby/vendor_ruby/**/*.rb"]
-    end
-
-    def install_changelog
-      changelog = Dir.glob(File.join(root, 'CHANGELOG*')).first
-      if changelog
-        run("dh_installchangelogs", "-p#{binary_package}", changelog, "upstream")
-      end
-    end
-
   end
 
 end
